@@ -18,7 +18,8 @@ properties:
         default: bar
 """
 
-BAR_SCHEMA = """definitions:
+BAR_SCHEMA = """$schema: "https://json-schema.org/draft/2020-12/schema#"
+definitions:
   bar:
     type: string
     description: bar entry
@@ -26,9 +27,10 @@ BAR_SCHEMA = """definitions:
 """
 
 BAR_JSON_SCHEMA = {
+    "$schema": "https://json-schema.org/draft/2020-12/schema#",
     "definitions": {
         "jsonbar": {"type": "string", "description": "bar entry", "default": "foo"}
-    }
+    },
 }
 
 DF_SCHEMA = """$schema: "https://json-schema.org/draft/2020-12/schema#"
@@ -131,7 +133,7 @@ def test_config_ref(config_schema_ref):
     # Make sure regular validator works
     config["param"]["bar"] = 1
     config["param"]["jsonbar"] = 2
-    from snakemake import WorkflowError
+    from snakemake.exceptions import WorkflowError
 
     with pytest.raises(WorkflowError):
         validate(config, str(config_schema_ref), False)
